@@ -572,6 +572,8 @@ class GenericObjectRestrictionTest(TestCase):
             self.HistoryOwnerToPermission.objects.filter(change_type=self.HistoryOwnerToPermission.TYPE_REMOVE).count(),
         )
 
+        self_role = 1
+
         # model save method
         otp = OwnerToPermission(permission=self.permission, owner=self.user, content_object=self.group)
         self.assertRaises(NoReasonSpecified, otp.save)
@@ -579,6 +581,9 @@ class GenericObjectRestrictionTest(TestCase):
         self.assertEqual(
             self.HistoryOwnerToPermission.objects.filter(change_type=self.HistoryOwnerToPermission.TYPE_ADD).count(), 2
         )
+        # user is a part of group of his own
+        self.assertTrue(self.user in self.user.users.all())
+        self.assertCountEqual(self.user.get_roles(self.user), [self_role])
         # role change
         self.assertEqual(
             self.HistoryOwnerToPermission.objects.filter(change_type=self.HistoryOwnerToPermission.TYPE_CHANGE).count(),
@@ -592,7 +597,6 @@ class GenericObjectRestrictionTest(TestCase):
         )
 
         # manager delete method
-
         self.assertRaises(NoReasonSpecified, OwnerToPermission.objects.all().delete)
         try:
             OwnerToPermission.objects.all().delete(reason=TEST_REASON, responsible=self.responsible_user)
@@ -605,7 +609,12 @@ class GenericObjectRestrictionTest(TestCase):
             2
         )
 
-        # manager bulk_create
+        # remove user from himself and add with other role
+        self.user.users.remove(self.user, reason=TEST_REASON)
+        custom_role = 2
+        self.user.users.add(self.user, roles=custom_role, reason=TEST_REASON)
+
+        # manager bulk_create method
         otps_to_create = [
             OwnerToPermission(permission=self.permission, owner=self.user, responsible=self.responsible_user),
             OwnerToPermission(permission=self.permission2, owner=self.user2, responsible=self.responsible_user),
@@ -620,6 +629,12 @@ class GenericObjectRestrictionTest(TestCase):
                 responsible=self.responsible_user,
             ).count(), 3
         )
+        # now user is a part of group of his own again and also has custom role
+        self.assertTrue(self.user in self.user.users.all())
+        self.assertCountEqual(self.user.get_roles(self.user), [self_role, custom_role])
+        # now user2 is a part of group of his own too
+        self.assertTrue(self.user2 in self.user2.users.all())
+        self.assertCountEqual(self.user2.get_roles(self.user2), [self_role])
 
     def test_gug_redefined_manager_methods(self):
         gug = GenericUserToGroup.objects.create(group=self.group, user=self.user, reason=TEST_REASON)
